<?php

/**
 * Editor. Assets.
 *
 * @package WPDesk\Library\WPCanvaEditor
 */
namespace FlexibleCouponsVendor\WPDesk\Library\WPCanvaEditor;

use FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
/**
 * Enqueue editor scripts.
 *
 * @package WPDesk\Library\WPCanvaEditor
 */
class Assets implements \FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable
{
    /**
     * @var string
     */
    private $post_type;
    /**
     * @var string
     */
    protected $scripts_version = '1.1';
    /**
     * @param $post_type
     */
    public function __construct($post_type)
    {
        $this->post_type = $post_type;
    }
    /**
     * Fires hooks
     */
    public function hooks()
    {
        \add_action('admin_enqueue_scripts', [$this, 'admin_enqueue_scripts']);
    }
    /**
     * @return string
     */
    protected function get_assets_url()
    {
        return \trailingslashit(\plugin_dir_url(__DIR__)) . 'assets/';
    }
    /**
     * Enqueue editor scripts and styles.
     */
    public function admin_enqueue_scripts()
    {
        $screen = \get_current_screen();
        $suffix = \defined('SCRIPT_DEBUG') && \SCRIPT_DEBUG ? '' : '.min';
        $is_pl = 'pl_PL' === \get_locale();
        $pro_url = $is_pl ? 'https://www.wpdesk.pl/sklep/flexible-coupons-woocommerce/?utm_source=flexible-coupons-product-edition&amp;utm_medium=link&amp;utm_campaign=flexible-coupons-pro' : 'https://www.wpdesk.net/products/flexible-coupons-woocommerce/?utm_source=flexible-coupons-product-edition&amp;utm_medium=link&amp;utm_campaign=flexible-coupons-pro';
        if ('post' === $screen->base && $this->post_type === $screen->post_type) {
            if (!\is_rtl()) {
                \wp_enqueue_style('canva-editor-admin', $this->get_assets_url() . 'css/admin.css', [], $this->scripts_version);
            } else {
                \wp_enqueue_style('canva-editor-admin-rtl', $this->get_assets_url() . 'css/admin-rtl.css', [], $this->scripts_version);
            }
            \wp_enqueue_media();
            \wp_register_script('flexible-coupons', $this->get_assets_url() . 'js/wpdesk-canva-editor' . $suffix . '.js', array('wp-editor'), $this->scripts_version, \true);
            \wp_enqueue_script('flexible-coupons');
            \wp_localize_script('flexible-coupons', 'wpdesk_canva_editor_lang', array('general' => \esc_html__('General', 'flexible-coupons'), 'images' => \esc_html__('Images', 'flexible-coupons'), 'text' => \esc_html__('Text', 'flexible-coupons'), 'shortcodes' => \esc_html__('Shortcodes', 'flexible-coupons'), 'select_format' => \esc_html__('Select format', 'flexible-coupons'), 'page_orientation' => \esc_html__('Page orientation', 'flexible-coupons'), 'vertical' => \esc_html__('Vertical', 'flexible-coupons'), 'horizontal' => \esc_html__('Horizontal', 'flexible-coupons'), 'background_color' => \esc_html__('Background color', 'flexible-coupons'), 'color' => \esc_html__('Color', 'flexible-coupons'), 'select' => \esc_html__('Select', 'flexible-coupons'), 'select_images' => \esc_html__('Select images', 'flexible-coupons'), 'add_to_area' => \esc_attr__('Add to area', 'flexible-coupons'), 'remove_from_project' => \esc_attr__('Remove from project', 'flexible-coupons'), 'edit' => \esc_attr__('Edit', 'flexible-coupons'), 'fit_to_screen' => \esc_attr__('Fit to screen', 'flexible-coupons'), 'crop' => \esc_attr__('Crop', 'flexible-coupons'), 'layer_up' => \esc_attr__('Layer up', 'flexible-coupons'), 'layer_down' => \esc_attr__('Layer down', 'flexible-coupons'), 'clone_element' => \esc_attr__('Clone element', 'flexible-coupons'), 'delete_element' => \esc_attr__('Delete element', 'flexible-coupons'), 'delete' => \esc_attr__('Delete element', 'flexible-coupons'), 'change_image' => \esc_attr__('Change image', 'flexible-coupons'), 'align_right' => \esc_attr__('Align right', 'flexible-coupons'), 'align_left' => \esc_attr__('Align left', 'flexible-coupons'), 'align_center' => \esc_attr__('Align center', 'flexible-coupons'), 'justify' => \esc_attr__('Justify', 'flexible-coupons'), 'font_size' => \esc_attr__('Font size', 'flexible-coupons'), 'change_font_size' => \esc_attr__('Change font size', 'flexible-coupons'), 'font_family' => \esc_attr__('Font family', 'flexible-coupons'), 'change_font_family' => \esc_attr__('Change font family', 'flexible-coupons'), 'double_click_to_edit' => \esc_attr__('Double click to edit', 'flexible-coupons'), 'font_color' => \esc_attr__('Font color', 'flexible-coupons'), 'header1' => \esc_html__('Header 1', 'flexible-coupons'), 'header2' => \esc_html__('Header 2', 'flexible-coupons'), 'header3' => \esc_html__('Header 3', 'flexible-coupons'), 'content' => \esc_html__('Content', 'flexible-coupons'), 'upgrade_to_pro' => \esc_html__('Upgrade to PRO and enable more shortcodes →', 'flexible-coupons'), 'pro_url' => $pro_url));
            \wp_register_script('wp-canva-admin', $this->get_assets_url() . 'js/admin.js', array('flexible-coupons'), $this->scripts_version, \true);
            \wp_enqueue_script('wp-canva-admin');
            \wp_localize_script('wp-canva-admin', 'wp_canva_admin', array('post_type' => $this->post_type, 'nonce' => \wp_create_nonce('editor_save_post_' . $this->post_type), 'lang' => \get_locale()));
        }
    }
}
