<?php

/**
 * Implementation of the library.
 *
 * @package WPDesk\Library\WPCoupons
 */
namespace FlexibleCouponsVendor\WPDesk\Library\WPCoupons;

use Psr\Log\LoggerInterface;
use Psr\Log\NullLogger;
use FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\EditorIntegration;
use FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\Shortcode;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\NullProductFields;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\PostMeta;
use FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\ProductFields;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Shortcodes;
use FlexibleCouponsVendor\WPDesk\Persistence\Adapter\WordPress\WordpressOptionsContainer;
use FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\HookableCollection;
use FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\HookableParent;
use FlexibleCouponsVendor\WPDesk\View\Renderer\Renderer;
use FlexibleCouponsVendor\WPDesk\View\Renderer\SimplePhpRenderer;
use FlexibleCouponsVendor\WPDesk\View\Resolver\ChainResolver;
use FlexibleCouponsVendor\WPDesk\View\Resolver\DirResolver;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Settings;
/**
 * Main class for the implementation of the coupon library.
 *
 * @package WPDesk\Library\WPCoupons
 */
class CouponsIntegration implements \FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable, \FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\HookableCollection
{
    use HookableParent;
    /**
     * @var EditorIntegration
     */
    private $editor;
    /**
     * @var Renderer
     */
    private $renderer;
    /**
     * @var ProductFields
     */
    private $product_fields;
    /**
     * @var array
     */
    private $forms;
    /**
     * @var LoggerInterface
     */
    private $logger;
    private static $is_pro = \false;
    /**
     * @param EditorIntegration $editor
     */
    public function __construct(\FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\EditorIntegration $editor)
    {
        $this->editor = $editor;
        $this->init_render();
        $this->set_product_fields(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\NullProductFields());
        $this->set_logger(new \Psr\Log\NullLogger());
    }
    public static function set_pro()
    {
        self::$is_pro = \true;
    }
    /**
     * @return bool
     */
    public static function is_pro() : bool
    {
        return self::$is_pro;
    }
    /**
     * @param LoggerInterface $logger
     */
    public function set_logger(\Psr\Log\LoggerInterface $logger)
    {
        $this->logger = $logger;
    }
    /**
     * @return LoggerInterface
     */
    private function get_logger() : \Psr\Log\LoggerInterface
    {
        return $this->logger;
    }
    /**
     * @return Renderer
     */
    private function get_renderer() : \FlexibleCouponsVendor\WPDesk\View\Renderer\Renderer
    {
        return $this->renderer;
    }
    /**
     * Init renderer.
     */
    private function init_render()
    {
        $resolver = new \FlexibleCouponsVendor\WPDesk\View\Resolver\ChainResolver();
        $resolver->appendResolver(new \FlexibleCouponsVendor\WPDesk\View\Resolver\DirResolver(\trailingslashit(__DIR__) . 'Views/dashboard'));
        $resolver->appendResolver(new \FlexibleCouponsVendor\WPDesk\View\Resolver\DirResolver(\trailingslashit(__DIR__) . 'Views/editor'));
        $this->renderer = new \FlexibleCouponsVendor\WPDesk\View\Renderer\SimplePhpRenderer($resolver);
    }
    /**
     * @param ProductFields $product_fields
     */
    public function set_product_fields(\FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\ProductFields $product_fields)
    {
        $this->product_fields = $product_fields;
    }
    /**
     * @return ProductFields
     */
    private function get_product_fields() : \FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\ProductFields
    {
        return $this->product_fields;
    }
    /**
     * @return Shortcode[]
     */
    protected function shortcodes_definition() : array
    {
        return [new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Shortcodes\CouponCode(), new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Shortcodes\CouponValue()];
    }
    protected function get_persistence() : \FlexibleCouponsVendor\WPDesk\Persistence\Adapter\WordPress\WordpressOptionsContainer
    {
        return new \FlexibleCouponsVendor\WPDesk\Persistence\Adapter\WordPress\WordpressOptionsContainer('flexible_coupons_');
    }
    /**
     * @return void
     */
    public function hooks()
    {
        $editor_post_type = $this->editor->get_post_type();
        $renderer = $this->get_renderer();
        $product_fields = $this->get_product_fields();
        $shortcodes = new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Shortcodes\Shortcodes($this->shortcodes_definition());
        $post_meta = new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\PostMeta();
        $settings = $this->get_persistence();
        $pdf = new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\PDF\PDFRenderer($this->editor, $renderer, $product_fields, $post_meta, $shortcodes);
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\Assets($editor_post_type, $shortcodes));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Cart\Cart($product_fields, $post_meta, $settings, $this->get_logger()));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\MyAccount($renderer, $post_meta));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Order\MakeOrder($post_meta));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Order\OrderMetaBox($renderer, $post_meta));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Coupon\CouponsProcessing($renderer, $product_fields, $pdf, $settings, $post_meta, $this->get_logger()));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Settings\SettingsForm($settings));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Product\ProductEditPage($settings, $renderer, $product_fields, $post_meta, $editor_post_type));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Product\ProductVariationEditPage($settings, $renderer, $product_fields, $post_meta, $editor_post_type));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Product\SaveProductSimpleData($product_fields, $post_meta));
        $this->add_hookable(new \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Product\SaveProductVariationData($product_fields, $post_meta));
        $this->hooks_on_hookable_objects();
    }
}
