<?php

namespace FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Email;

use WC_Email;
use FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\Email;
/**
 * Base email template.
 *
 * @package WPDesk\Library\WPCoupons\Email
 */
class FlexibleCouponsBaseEmail extends \WC_Email implements \FlexibleCouponsVendor\WPDesk\Library\CouponInterfaces\Email
{
    const SLUG = 'FlexibleCouponsEmail';
    const SLUG_RECIPIENT = 'FlexibleCouponsRecipientEmail';
    /**
     * Coupon meta data.
     *
     * @var array
     */
    private $meta;
    /**
     * @param string $template_path Email template path.
     */
    public function __construct(string $template_path)
    {
        $this->template_base = $template_path;
        $this->customer_email = \true;
        $this->manual = \true;
        parent::__construct();
    }
    /**
     * Get HTML content.
     *
     * @return string
     */
    public function get_content_html() : string
    {
        \ob_start();
        \wc_get_template($this->template_html, array('order' => $this->object, 'email_heading' => $this->get_heading(), 'meta' => $this->meta, 'email' => $this->customer_email, 'order_number' => $this->object->get_order_number(), 'date_order' => \date_i18n(\wc_date_format(), $this->object->get_date_created() ? $this->object->get_date_created()->getTimestamp() : \current_time('timestamp')), 'sent_to_admin' => \false, 'plain_text' => \false), '', $this->template_base);
        return \ob_get_clean();
    }
    /**
     * Get plain content.
     *
     * @return string
     */
    public function get_content_plain() : string
    {
        \ob_start();
        \wc_get_template($this->template_plain, array('order' => $this->object, 'email_heading' => $this->get_heading(), 'meta' => $this->meta, 'email' => $this->customer_email, 'order_number' => $this->object->get_order_number(), 'date_order' => \date_i18n(\wc_date_format(), $this->object->get_date_created() ? $this->object->get_date_created()->getTimestamp() : \current_time('timestamp')), 'sent_to_admin' => \false, 'plain_text' => \true), '', $this->template_base);
        return \ob_get_clean();
    }
    /**
     * Initialise Settings Form Fields
     *
     * @return void
     */
    public function init_form_fields()
    {
        $this->form_fields = array('subject' => array('title' => \esc_html__('Subject', 'woocommerce'), 'type' => 'text', 'placeholder' => $this->subject, 'default' => ''), 'heading' => array('title' => \esc_html__('Email Heading', 'woocommerce'), 'type' => 'text', 'placeholder' => $this->heading, 'default' => ''), 'email_type' => array('title' => \esc_html__('Email type', 'woocommerce'), 'type' => 'select', 'description' => \esc_html__('Choose which format of email to send.', 'woocommerce'), 'default' => 'html', 'class' => 'email_type', 'options' => array('plain' => \esc_html__('Plain text', 'woocommerce'), 'html' => \esc_html__('HTML', 'woocommerce'), 'multipart' => \esc_html__('Multipart', 'woocommerce'))));
    }
    /**
     * @param int   $order_id
     * @param array $meta
     */
    public function send_mail($order_id, $meta)
    {
        $order = \wc_get_order(\absint($order_id));
        if (!$order) {
            return;
        }
        $recipient_email = $order->get_billing_email();
        if (isset($meta['flexible_coupon_recipient_email']) && \is_email($meta['flexible_coupon_recipient_email'])) {
            $recipient_email = $meta['flexible_coupon_recipient_email'];
        }
        $this->object = $order;
        $this->recipient = $recipient_email;
        $this->meta = $meta;
        $this->placeholders['{order_date}'] = \date_i18n(\wc_date_format(), $order->get_date_created() ? $order->get_date_created()->getTimestamp() : \current_time('timestamp'));
        $this->placeholders['{order_number}'] = $order->get_order_number();
        if (empty($this->get_recipient())) {
            return;
        }
        $this->send($this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), array());
    }
}
